# Open Source Download Link 





# Copyright Information 
## LICENSE  
> Copyright (C) 2021  Matt Belfast Brown  
>   
> This program is free software: you can redistribute it and/or modify  
> it under the terms of the GNU General Public License as published by  
> the Free Software Foundation, either version 3 of the License, or  
> (at your option) any later version.  
>    
> This program is distributed in the hope that it will be useful,  
> but WITHOUT ANY WARRANTY; without even the implied warranty of  
> MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
> GNU General Public License for more details.  
>   
> You should have received a copy of the GNU General Public License  
> along with this program.  If not, see <https://www.gnu.org/licenses/>.  

## Author and Version
> Author: ***Matt Belfast Brown*** or *Matt Brown* or *M.B.B.*（ **Name in English** ）  
>> Also be called ***The Day of The Doctor*** ( **Network Nickname** )  
>>> ***鈴木夢美*** or ***伊藤京介*** ( **Name in Japanese** )  
>>> ***沈永基***，***皓月***，***飞瀑山人***，***衍枫阁主人*** ( **Name in Chinese, Style Name, Pseudonym, Alias** ) 
    
>> Contact Details:  
>>> E-mail:*thedayofthedo@gmail.com* or *thedayofthedoctor@foxmail.com*  
>>> TEL: \+86-15841486187  
>>> Address:**Room 125, Apartment No. 4, West District, North Campus, Northwest A&F University, No. 22, Xinong Road, Litai Street, Yangling District, Xianyang City, Shaanxi Province, China**  
>>> Address:*中国陕西省杨凌区李台街道西农路22号西北农林科技大学南校区南区14号公寓313宿舍*  
   
> Version:  
>> First Edition Time:2021-07-10  
>> Last Revision Time:2021-08-20  
>> Version Number:0.3.9  
>> Version Update Log:
>>> 更新ReadME文档 
>>> 完善代码结构 
>>> 添加新代码-重樱舰船名对照